#!/usr/bin/env python


## Copyright (c) 2005 Brian Turcotte ("shaja")
##
## Permission is hereby granted, free of charge, to any person
## obtaining a copy of this software and associated documentation
## files (the "Software"), to deal in the Software without
## restriction, including without limitation the rights to use,
## copy, modify, merge, publish, distribute, sublicense, and/or sell
## copies of the Software, and to permit persons to whom the
## Software is furnished to do so, subject to the following
## conditions:
##
## The above copyright notice and this permission notice shall be
## included in all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
## EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
## OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
## NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
## HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
## WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
## FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
## OTHER DEALINGS IN THE SOFTWARE.

# 12/21/2005
# 1.0

import Image, ImageDraw
import PngImagePlugin
import random, math

def vCheckersTB(size=(64,64)):
    quadsize = (size[0] / 2, size[1] / 2)
    im = Image.new('L', size)
    for x in range(quadsize[0]):
        for y in range(size[1]):
            color = 256.0 / size[1] * y
            im.putpixel((x, y), color)
            im.putpixel((x + quadsize[0], (y + quadsize[1]) % size[1]), color)
    return im

def vCheckersCO(size=(64,64)):
    quadsize = (size[0] / 2, size[1] / 2)
    im = Image.new('L', size)
    for x in range(quadsize[0]):
        for y in range(quadsize[1]):
            color = 256.0 / quadsize[1] * y
            im.putpixel((x, y), color)
            im.putpixel((x, y + quadsize[1]), 256 - color)
            im.putpixel((x + quadsize[0], (y + quadsize[1]) % size[1]), color)
            im.putpixel((x + quadsize[0], y), 256 - color)
    return im

def hCheckersLR(size=(64,64)):
    quadsize = (size[0] / 2, size[1] / 2)
    im = Image.new('L', size)
    for y in range(quadsize[1]):
        for x in range(size[0]):
            color = 256.0 / size[0] * x
            im.putpixel((x, y), color)
            im.putpixel(((x + quadsize[0]) % size[0], y + quadsize[1]), color)
    return im

def hCheckersCO(size=(64,64)):
    quadsize = (size[0] / 2, size[1] / 2)
    im = Image.new('L', size)
    for y in range(quadsize[1]):
        for x in range(quadsize[0]):
            color = 256.0 / quadsize[0] * x
            im.putpixel((x, y), color)
            im.putpixel((x + quadsize[0], y), 256 - color)
            im.putpixel(((x + quadsize[0]) % size[0], y + quadsize[1]), color)
            im.putpixel((x, y + quadsize[1]), 256 - color)
    return im

def vBlindsLR(size=64):
    im = Image.new('L', (size, 1))
    for x in range(size):
        im.putpixel((x, 0), 256.0 / size * x)
    return im

def vBlindsCO(size=64):
    half = size / 2
    im = Image.new('L', (size, 1))
    for x in range(half):
        im.putpixel((x, 0), 256.0 / half * x)
        im.putpixel((x + half, 0), 256 - (256.0 / half * x))
    return im
        
def hBlindsTB(size=64):
    im = Image.new('L', (1, size))
    for y in range(size):
        im.putpixel((0, y), 256.0 / size * y)
    return im

def hBlindsCO(size=64):
    half = size / 2
    im = Image.new('L', (1, size))
    for y in range(half):
        im.putpixel((0, y), 256.0 / half * y)
        im.putpixel((0, y + half), 256 - (256.0 / half * y))
    return im     

def diamonds(size=(40,40), dark=0, bright=256):
    quadsize = (size[0] / 2, size[1] / 2)
    im = Image.new('L', (size[0], size[1]))
    tlbrtile = gradientTileBLTR(quadsize, bright, dark, dark, bright)
    im.paste(tlbrtile, (0,0))
    im.paste(tlbrtile, quadsize)
    bltrtile = gradientTileTLBR(quadsize, dark, bright, bright, dark)
    im.paste(bltrtile, (0, quadsize[1]))
    im.paste(bltrtile, (quadsize[0], 0))
    return im
    
def diamondsHSweep(size=(40,40), hres=800, gradientsize=64):
    htiles = hres / size[0]
    if hres % size[0]:
        htiles += 1 # make an extra to avoid edge space
    whitegradient = gradient(htiles * 2, 0, 256 - gradientsize)
    whitegradient.append(256 - gradientsize)
    blackgradient = gradient(htiles * 2, gradientsize, 256)
    blackgradient.append(256)
    im = Image.new('L', (htiles * size[0], size[1]))
    quadsize = (size[0] / 2, size[1] / 2)
    xoffset = 0
    for i in range(htiles):
        #print "i:", i, "xoffset:", xoffset
        tltile = gradientTileBLTR(quadsize, whitegradient[i*2], blackgradient[i*2+1],
                                  blackgradient[i*2], whitegradient[i*2+1])
        im.paste(tltile, (xoffset, 0))
        bltile = gradientTileTLBR(quadsize, blackgradient[i*2], whitegradient[i*2+1],
                                  whitegradient[i*2], blackgradient[i*2+1])
        im.paste(bltile, (xoffset, quadsize[1]))
        xoffset += quadsize[0]
        trtile = gradientTileTLBR(quadsize, blackgradient[i*2+1], whitegradient[i*2+2],
                                  whitegradient[i*2+1], blackgradient[i*2+2])
        im.paste(trtile, (xoffset, 0))
        brtile = gradientTileBLTR(quadsize, whitegradient[i*2+1], blackgradient[i*2+2],
                                  blackgradient[i*2+1], whitegradient[i*2+2])
        im.paste(brtile, (xoffset, quadsize[1]))
        xoffset += quadsize[0]
    if hres % size[0]:
        cut = (im.size[0] - hres) / 2
        return im.crop((cut, 0, hres + cut, size[1]))
    else:    
        return im

def diamondsVSweep(size=(40,40), vres=600, gradientsize=64):
    vtiles = vres / size[1]
    #origvtiles = vtiles
    if vres % size[1]:
        vtiles += 1 # make an extra tile to avoid edge space
    whitegradient = gradient(vtiles * 2, 0, 256 - gradientsize)
    whitegradient.append(256 - gradientsize)
    blackgradient = gradient(vtiles * 2, gradientsize, 256)
    blackgradient.append(256)
    im = Image.new('L', (size[0], vtiles * size[1]))
    quadsize = (size[0] / 2, size[1] / 2)
    yoffset = 0
    for i in range(vtiles):
        tltile = gradientTileBLTR(quadsize, whitegradient[i*2], blackgradient[i*2],
                                  blackgradient[i*2+1], whitegradient[i*2+1])
        im.paste(tltile, (0, yoffset))
        trtile = gradientTileTLBR(quadsize, blackgradient[i*2], whitegradient[i*2],
                                  whitegradient[i*2+1], blackgradient[i*2+1])
        im.paste(trtile, (quadsize[0], yoffset))
        yoffset += quadsize[1]
        bltile = gradientTileTLBR(quadsize, blackgradient[i*2+1], whitegradient[i*2+1],
                                  whitegradient[i*2+2], blackgradient[i*2+2])
        im.paste(bltile, (0, yoffset))
        brtile = gradientTileBLTR(quadsize, whitegradient[i*2+1], blackgradient[i*2+1],
                                  blackgradient[i*2+2], whitegradient[i*2+2])
        im.paste(brtile, (quadsize[0], yoffset))
        yoffset += quadsize[1]
    if vres % size[1]:
        cut = (im.size[1] - vres) / 2
        print im.size
        print 0, cut, size[0], vres + cut
        return im.crop((0, cut, size[0], vres + cut))
    else:    
        return im

def diamondsHVSweep(size=(40,40), hres=800, vres=600, gradientsize=64):
    htiles = hres / size[0]
    if hres % size[0]:
        htiles += 1
    vtiles = vres / size[1]
    if vres % size[1]:
        vtiles += 1
    tiles = htiles + vtiles - 1
    whitegradient = gradient(tiles * 2, 0, 256 - gradientsize)
    whitegradient.append(256 - gradientsize) # fencepost
    blackgradient = gradient(tiles * 2, gradientsize, 256)
    blackgradient.append(256)
    im = Image.new('L', (htiles * size[0], vtiles * size[1]))
    quadsize = (size[0] / 2, size[1] / 2)
    yoffset = 0
    for y in range(vtiles):
        xoffset = 0
        for x in range(htiles):
            tidx = (x + y) * 2
            #print "x, y:", x, y, "tileidx:", tidx
            tltile = gradientTileBLTR(quadsize, whitegradient[tidx], blackgradient[tidx+1],
                                      blackgradient[tidx], whitegradient[tidx+1])
            im.paste(tltile, (xoffset, yoffset))
            bltile = gradientTileTLBR(quadsize, blackgradient[tidx], whitegradient[tidx+1],
                                      whitegradient[tidx], blackgradient[tidx+1])
            im.paste(bltile, (xoffset, yoffset + quadsize[1]))
            xoffset += quadsize[0]
            trtile = gradientTileTLBR(quadsize, blackgradient[tidx+1], whitegradient[tidx+2],
                                      whitegradient[tidx+1], blackgradient[tidx+2])
            im.paste(trtile, (xoffset, yoffset))
            brtile = gradientTileBLTR(quadsize, whitegradient[tidx+1], blackgradient[tidx+2],
                                      blackgradient[tidx+1], whitegradient[tidx+2])
            im.paste(brtile, (xoffset, yoffset + quadsize[1]))
            xoffset += quadsize[0]
        yoffset += size[1]
    if hres % size[0] or vres % size[1]:
        hcut = (im.size[0] - hres) / 2
        vcut = (im.size[1] - vres) / 2
        return im.crop((hcut, vcut, hres + hcut, vres + vcut))
    else:
        return im


def gradientTileBLTR(size=(64,64), tl=256, tr=128, bl=0, br=192):
    # Finally figured out that I have to interpolate the diagonal edge, too. Doh.
    hsize, vsize = size
    tlbrgradient = gradient(vsize, tl, br)
    tlbrgradient.append(br) # fencepost
    tile = Image.new('L', (hsize, vsize))
    scale = float(hsize) / vsize
    #print "scale:", scale
    for y in range(vsize):
        blgradient = gradient(hsize, bl, tlbrgradient[y])
        trgradient = gradient(hsize, tr, tlbrgradient[y])
        trgradient.reverse()
        igradient = []
        igradient.extend(blgradient)
        igradient.extend(trgradient)
        for x in range(hsize):
            tile.putpixel((x, y), igradient[x + hsize - int(y * scale)])
    return tile

def gradientTileTLBR(size=(64,64), tl=0, tr=256, bl=192, br=128):
    # Finally figured out that I have to interpolate the diagonal edge, too. Doh.
    hsize, vsize = size
    trblgradient = gradient(vsize, tr, bl)
    trblgradient.append(bl) # fencepost
    tile = Image.new('L', (hsize, vsize))
    scale = float(hsize) / vsize
    #print "scale:", scale
    for y in range(vsize):
        tlgradient = gradient(hsize, tl, trblgradient[y])
        brgradient = gradient(hsize, br, trblgradient[y])
        brgradient.append(trblgradient[y]) # fencepost
        brgradient.reverse()
        igradient = []
        igradient.extend(tlgradient)
        igradient.extend(brgradient)
        for x in range(hsize):
            tile.putpixel((x, y), igradient[int(y * scale) + x])
    return tile

def gradienthline(size, floor, ceiling):
    gradient = []
    for i in range(size):
        gradient.append((255.0 / size) * i)
    gradient = normalize(gradient, floor, ceiling)
    im = Image.new('L', (size, 1))
    for i in range(size):
        im.putpixel((i, 0), gradient[i])
    return im

def gradient(size, floor, ceiling):
    # the ceiling is what would follow gradient[-1] - it will never be
    # reached in the gradient itself. It must be so, for the good of Math.
    scale = ceiling - floor
    gradient = []
    for i in range(size):
        gradient.append(float(scale) / size * i + floor)
    return gradient

def blindsHSweepLR(width=64, hres=800, gradientsize=64):
    # min to max across tile
    htiles = hres / width
    if hres % width:
        htiles += 1  # make an extra to avoid edge space
    whitegradient = gradient(htiles, 0, 256 - gradientsize)
    whitegradient.append(256 - gradientsize)
    blackgradient = gradient(htiles, gradientsize, 256)
    blackgradient.append(256)
    im = Image.new('L', (htiles * width, 1))
    xoffset = 0
    for i in range(htiles):
        #print "i:", i, "xoffset:", xoffset
        tilegradient = gradient(width, whitegradient[i], blackgradient[i])
        for x in range(width):
            im.putpixel((x + xoffset, 0), tilegradient[x])
        xoffset += width
    if hres % width:
        cut = (im.size[0] - hres) / 2
        return im.crop((cut, 0, hres + cut, 1))
    else:
        return im

def blindsHSweepCO(width=64, hres=800, gradientsize=64): # 3rd try
    # min to max to next min across tile
    htiles = hres / width
    if hres % width:
        htiles += 1 # extra to avoid edge space
    whitegradient = gradient(htiles, 0, 256 - gradientsize)
    whitegradient.append(256-gradientsize)
    blackgradient = gradient(htiles, gradientsize, 256)
    blackgradient.append(256)
    im = Image.new('L', (htiles * width, 1))
    xoffset = 0
    for i in range(htiles):
        print "i:", i, "xoffset:", xoffset
        tilegradient = gradient(width / 2, whitegradient[i], blackgradient[i])
        for x in range(width / 2):
            im.putpixel((x + xoffset, 0), tilegradient[x])
        xoffset += width / 2
        tilegradient = gradient(width / 2, blackgradient[i], whitegradient[i+1])
        for x in range(width / 2):
            im.putpixel((x + xoffset, 0), tilegradient[x])
        xoffset += width / 2
    if hres % width:
        cut = (im.size[0] - hres) / 2
        return im.crop((cut, 0, hres+cut, 1))
    else:
        return im

def blindsVSweepTB(height=64, vres=600, gradientsize=64):
    vtiles = vres / height
    if vres % height:
        vtiles += 1
    whitegradient = gradient(vtiles, 0, 256 - gradientsize)
    whitegradient.append(256-gradientsize) # last fencepost
    blackgradient = gradient(vtiles, gradientsize, 256)
    blackgradient.append(256) # last fencepost
    im = Image.new('L', (1, vtiles * height))
    yoffset = 0
    for i in range(vtiles):
        #print "i:", i, "yoffset:", yoffset
        tilegradient = gradient(height, whitegradient[i], blackgradient[i])
        for y in range(height):
            im.putpixel((0, y + yoffset), tilegradient[y])
        yoffset += height
    if vres % height:
        cut = (im.size[1] - vres) / 2
        return im.crop((0, cut, 1, vres + cut))
    else:
        return im
    

def blindsVSweepCO(height=64, vres=600, gradientsize=64):
    #tilesize = vres / tiles
    vtiles = vres / height
    if vres % height:
        vtiles += 1
    whitegradient = gradient(vtiles, 0, 256 - gradientsize)
    whitegradient.append(256-gradientsize) # last fencepost
    blackgradient = gradient(vtiles, gradientsize, 256)
    blackgradient.append(256) # last fencepost
    im = Image.new('L', (1, vtiles * height))
    yoffset = 0
    for i in range(vtiles):
        #print "i:", i, "yoffset:", yoffset
        tilegradient = gradient(height / 2, whitegradient[i], blackgradient[i])
        for y in range(height / 2):
            im.putpixel((0, y + yoffset), tilegradient[y])
        yoffset += height / 2
        tilegradient = gradient(height / 2, blackgradient[i], whitegradient[i+1])
        for y in range(height / 2):
            im.putpixel((0, y + yoffset), tilegradient[y])
        yoffset += height / 2
    if vres % height:
        cut = (im.size[1] - vres) / 2
        return im.crop((0, cut, 1, vres + cut))
    else:
        return im

def randTile(size=(64,64), subtilesize=(1,1)):
    im = Image.new('L', size)
    for x in range(size[0] / subtilesize[0]):
        for y in range(size[1] / subtilesize[1]):
            subim = Image.new('L', subtilesize, random.randint(0,255))
            im.paste(subim, (x * subtilesize[0], y * subtilesize[1]))
    return im

def angle(x1, y1, x2, y2):
    try:
        angle = math.degrees(math.atan(float(y1 - y2) / (x1 - x2)))
        return angle
    except ZeroDivisionError:
        # Math is hard. Let's go shopping. This doesn't work correctly for all possibilities.
        if y1 > y2:
            return -90.0
        else:
            return 90.0

def CCWRadialSweepArcs(size=(64,64), numarcs=8):
    # So many ugly bits for a decent result... sigh.
    width = size[0]
    height = size[1]
    center = (width / 2, height / 2)
    im = Image.new('L', (width, height), 128)
    draw = ImageDraw.Draw(im)

    # sigh.

    #quad TR
    x1 = width / 2
    y1 = height / 2 - 1
    for x2 in range(x1, width+1): 
        a = angle(x1, y1, x2, 0) + 90
        color = (255.0 / 360 * numarcs) * a % 255
        draw.line([x1, y1, x2, 0], fill=color)
        #print "(%d,%d) to (%d,%d) angle: %f color: %f" % (x1, y1, x2, 0, a, color)
    for y2 in range(0, y1+1):
        a = angle(x1, y1, width, y2) + 90
        color = (255.0 / 360 * numarcs) * a % 255
        draw.line([x1, y1, width, y2], fill=color)
        #print "(%d,%d) to (%d,%d) angle: %f color: %f" % (x1, y1, width, y2, a, color)

    # quad BR
    x1 = width / 2
    y1 = height / 2
    for y2 in range(y1, height+1): 
        a = angle(x1, y1, width, y2) + 90
        color = (255.0 / 360 * numarcs) * a % 255
        draw.line([x1, y1, width, y2], fill=color)
        #print "(%d,%d) to (%d,%d) angle: %f color: %f" % (x1, y1, width, y2, a, color)
    for x2 in range(x1, width+1):
        a = angle(x1, y1, x2, height) + 90
        color = (255.0 / 360 * numarcs) * a % 255
        draw.line([x1, y1, x2, height], fill=color)
        #print "(%d,%d) to (%d,%d) angle: %f color: %f" % (x1, y1, x2, height, a, color)

    #quad BL
    x1 = width / 2
    y1 = height / 2 - 1
    for x2 in range(0, x1 + 1): 
        a = angle(x2, height, x1, y1) + 270  # swap the endpoints because of the vertical
        color = (255.0 / 360 * numarcs) * a % 255
        draw.line([x1, y1, x2, height], fill=color)
        #print "(%d,%d) to (%d,%d) angle: %f color: %f" % (x1, y1, x2, height, a, color)
    for y2 in range(y1, height):
        a = angle(x1, y1, 0, y2) + 270
        color = (255.0 / 360 * numarcs) * a % 255
        draw.line([x1, y1, 0, y2], fill=color)
        #print "(%d,%d) to (%d,%d) angle: %f color: %f" % (x1, y1, 0, y2, a, color)
        
    #quad TL
    x1 = width / 2 - 1
    y1 = height / 2 - 1
    for y2 in range(0, height / 2):
        a = angle(x1, y1, 0, y2) + 270
        color = (255.0 / 360 * numarcs) * a % 255
        draw.line([x1, y1, 0, y2], fill=color)
        #print "(%d,%d) to (%d,%d) angle: %f color: %f" % (x1, y1, 0, y2, a, color)
    for x2 in range(0, width / 2):
        a = angle(x2, 0, x1, y1) + 270 # swap the endpoints because of the vertical
        color = (255.0 / 360 * numarcs) * a % 255
        draw.line([x1, y1, x2, 0], fill=color)
        #print "(%d,%d) to (%d,%d) angle: %f color: %f" % (x1, y1, x2, 0, a, color)
        
    del draw
    return im
    #return im.crop((1, 1, width-1, height-1))

def inputEven(prompt, minimum, maximum):
    while True:
        entry = raw_input(prompt)
        try:
            ientry = int(entry)
        except ValueError:
            print "Not a number..."
            ientry = -1
        if ientry >= minimum and ientry <= maximum and not(ientry % 2):
            return ientry
        print "Please enter an even number between %d and %d" % (minimum, maximum)

def inputAny(prompt, minimum, maximum):
    while True:
        entry = raw_input(prompt)
        try:
            ientry = int(entry)
        except ValueError:
            print "Not a number..."
            ientry = -1
        if ientry >= minimum and ientry <= maximum:
            return ientry
        print "Please enter a number between %d and %d" % (minimum, maximum)

def menuChoice(maxchoice):
    while True:
        entry = raw_input("Menu choice?")
        try:
            ientry = int(entry)
        except ValueError:
            print "Not a number..."
            ientry = -1
        if ientry <= maxchoice:
            return ientry
        print "Menu choice must be a number between 0 and %d" % maxchoice

def inputTileSize():
    width = inputEven("Width of tile (2-1024)?", 2, 1024)
    height = inputEven("Height of tile (2-1024)?", 2, 1024)
    return width, height

def pgen(name):
    print "\nGenerating %s ..." % name

def psave(name):
    print "Saving %s ..." % name

def menu():
    maxchoice = 18
    print
    print "0: Quit"
    print "1: Vertical checkers top/bottom"
    print "2: Vertical checkers center-out"
    print "3: Horizontal checkers left/right"
    print "4: Horizontal checkers center-out"
    print "5: Vertical blinds left/right"
    print "6: Vertical blinds center-out"
    print "7: Horizontal blinds top/bottom"
    print "8: Horizontal blinds center-out"
    print "9: Vertical blinds (left/right) sweep"
    print "10: Vertical blinds (center-out) sweep"
    print "11: Horizontal blinds (top/bottom) sweep"
    print "12: Horizontal blinds (center-out) sweep"
    print "13: Diamonds"
    print "14: Diamonds horizontal sweep"
    print "15: Diamonds vertical sweep"
    print "16: Diamonds diagonal sweep"
    print "17: Noise"
    print "18: Counter-clockwise radial sweep"
    
    choice = menuChoice(maxchoice)
    if choice == 0:
        print "\nBye!"
        return False
    elif choice == 1:  # vCheckersTB
        print "\nVertical checkers top / bottom"
        width, height = inputTileSize()
        name = "vcheckerstb%dx%d.png" % (width, height)
        pgen(name)
        im = vCheckersTB((width, height))
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 2:
        print "\nVertical checkers center-out"
        width, height = inputTileSize()
        name = "vcheckersco%dx%d.png" % (width, height)
        pgen(name)
        im = vCheckersCO((width, height))
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 3:
        print "\nHorizontal checkers left / right"
        width, height = inputTileSize()
        name = "hcheckerslr%dx%d.png" % (width, height)
        pgen(name)
        im = hCheckersLR((width, height))
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 4:
        print "\nHorizontal checkers center-out"
        width, height = inputTileSize()
        name = "hcheckersco%dx%d.png" % (width, height)
        pgen(name)
        im = hCheckersCO((width, height))
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 5:
        print "\nVertical blinds left/right"
        width = inputEven("Width of single blind (2-1024)?", 2, 1024)
        name = "vblindslr%d.png" % width
        pgen(name)
        im = vBlindsLR(width)
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 6:
        print "\nVertical blinds center-out"
        width = inputEven("Width of single blind (2-1024)?", 2, 1024)
        name = "vblindsco%d.png" % width
        pgen(name)
        im = vBlindsCO(width)
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 7:
        print "\nHorizontal blinds top/bottom"
        height = inputEven("Height of a single blind (2-1024)?", 2, 1024)
        name = "hblindstb%d.png" % height
        pgen(name)
        im = hBlindsTB(height)
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 8:
        print "\nHorizontal blinds center-out"
        height = inputEven("Height of a single blind (2-1024)?", 2, 1024)
        name = "hblindsco%d.png" % height
        pgen(name)
        im = hBlindsCO(height)
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 9:
        print "\nVertical blinds (left / right) sweep"
        width = inputEven("Width of a single blind (2-1024)?", 2, 1024)
        hres = inputEven("Width of the screen?", 320, 2048)
        grad = inputEven("Size of the gradient (8-254)?", 8, 254)
        name = "blindshsweeplr%dr%d.png" % (width, grad)
        pgen(name)
        im = blindsHSweepLR(width, hres, grad)
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 10:
        print "\nVertical blinds (center-out) sweep"
        width = inputEven("Width of a single blind (2-1024)?", 2, 1024)
        hres = inputEven("Width of the screen?", 320, 2048)
        grad = inputEven("Size of the gradient (8-254)?", 8, 254)
        name = "blindshsweepco%dr%d.png" % (width, grad)
        pgen(name)
        im = blindsHSweepCO(width, hres, grad)
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 11:
        print "\nHorizontal blinds (top/bottom) sweep"
        height = inputEven("Height of a single blind (2-1024)?", 2, 1024)
        vres = inputEven("Height of the screen?", 200, 2048)
        grad = inputEven("Size of the gradient (8-254)?", 8, 254)
        name = "blindsvsweeptb%dr%d.png" % (height, grad)
        pgen(name)
        im = blindsVSweepTB(height, vres, grad)
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 12:
        print "\nHorizontal blinds (center-out) sweep"
        height = inputEven("Height of a single blind (2-1024)?", 2, 1024)
        vres = inputEven("Height of the screen?", 200, 2048)
        grad = inputEven("Size of the gradient (8-254)?", 8, 254)
        name = "blindsvsweepco%dr%d.png" % (height, grad)
        pgen(name)
        im = blindsVSweepCO(height, vres, grad)
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 13:
        print "\nDiamonds"
        width, height = inputTileSize()
        name = "diamonds%dx%d.png" % (width, height)
        pgen(name)
        im = diamonds((width, height))
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 14:
        print "\nDiamonds horizontal sweep"
        width, height = inputTileSize()
        hres = inputEven("Width of the screen?", 320, 2048)
        grad = inputEven("Size of the gradient (8-254)?", 8, 254)
        name = "diamondshsweep%dx%dr%d.png" % (width, height, grad)
        pgen(name)
        im = diamondsHSweep((width, height), hres, grad)
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 15:
        print "\nDiamonds vertical sweep"
        width, height = inputTileSize()
        vres = inputEven("Height of the screen?", 200, 2048)
        grad = inputEven("Size of the gradient (8-254)?", 8, 254)
        name = "diamondsvsweep%dx%dr%d.png" % (width, height, grad)
        pgen(name)
        im = diamondsVSweep((width, height), vres, grad)
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 16:
        print "\nDiamonds diagonal sweep"
        width, height = inputTileSize()
        hres = inputEven("Width of the screen?", 320, 2048)
        vres = inputEven("Height of the screen?", 200, 2048)
        grad = inputEven("Size of the gradient (8-254)?", 8, 254)
        name = "diamondshvsweep%dx%dr%d.png" % (width, height, grad)
        pgen(name)
        im = diamondsHVSweep((width, height), hres, vres, grad)
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 17:
        print "\nNoise"
        width, height = inputTileSize()
        subwidth = inputAny("Width of subtile (1-%d)?" % width, 1, width)
        subheight = inputAny("Height of subtile (1-%d)?" % height, 1, height)
        name = "noise%dx%d.png" % (width, height)
        pgen(name)
        im = randTile((width, height), (subwidth, subheight))
        psave(name)
        im.save(name)
        print "Done."
    elif choice == 18:
        print "\nCounter-clockwise radial sweep"
        width, height = inputTileSize()
        numarcs = inputAny("Number of gradient arcs (1-360)?", 1, 360)
        name = "ccwradial%dx%da%d.png" % (width, height, numarcs)
        pgen(name)
        im = CCWRadialSweepArcs((width, height), numarcs)
        psave(name)
        im.save(name)
        print "Done."
  
    return True

            
def main():
    more = True
    while more:
        more = menu()

if __name__ == '__main__':
    main()